@@ -6,7 +6,7 @@ class Block:
 
 	progression = Blues.standard_blues
 	
-	bpm = 250
+	bpm = 120
 	iterations = 8
 	resolution = 8
 
@@ -45,11 +45,11 @@ class Block:
 	def get_resolution(self, iteration):
 		return self.resolution
 
-	def get_tick_length(self, iteration, tick_length):
+	def get_tick_length(self, tick, tick_length):
 		if not self.swing:
 			return tick_length
 		else:
-			if iteration % 2 == 0:
+			if tick % 2 == 0:
 				return tick_length * 1.33
 			else:
 				return tick_length * 0.66
