@@ -37,7 +37,7 @@ class Sequencer:
 	
 	def block_tick(self):
 		sleep(self.block.get_tick_length(\
-			self.iterations, self.tick_length))
+			self.tick, self.tick_length))
 		self.set_bpm(self.block.get_bpm(self.iterations))
 
 
@@ -79,9 +79,10 @@ class Sequencer:
 					if n not in self.state["scale"]:
 						self.replace_scale_note(n)
 
+			self.tick = i % ticks
 			self.state["chord"] = chord
 			self.state["progression_index"] = i / self.resolution
-			self.state["tick"] = i % ticks
+			self.state["tick"] = self.tick
 			self.state["ticks"] = ticks
 			self.state["iteration_tick"] = i
 			self.state["wild"] = self.wild
